@@ -31,6 +31,12 @@
 #include "gen.h"
 #include "trans.h"
 
+#if STDC_HEADERS || HAVE_STRING_H
+#include <string.h>
+#else /* not STDC_HEADERS and not HAVE_STRING_H */
+#include <strings.h>
+#endif /* not STDC_HEADERS and not HAVE_STRING_H */
+
 #if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -330,7 +336,9 @@ basename (str) char *str;
   str= newstrcat1 (str);
   i= strlen (str);
   if (i > 4 && !(strcmp (&str[i - 4], ".sim")
-		 && strcmp (&str[i - 4], ".cim")))
+		 && strcmp (&str[i - 4], ".SIM")
+		 && strcmp (&str[i - 4], ".cim")
+		 && strcmp (&str[i - 4], ".CIM")))
     str[i - 4] = '\0';
   
   return str;
@@ -645,7 +653,9 @@ static parseoptions (argc, argv)
 	      print_help (1);
 	    };
 	  if (l > 4 && !(strcmp (&argv[index][l - 4], ".sim")
-			 && strcmp (&argv[index][l - 4], ".cim")))
+			 && strcmp (&argv[index][l - 4], ".SIM")
+			 && strcmp (&argv[index][l - 4], ".cim")
+			 && strcmp (&argv[index][l - 4], ".CIM")))
 	    sourcename = newstrcat1 (argv[index]);
 	  else
 	    sourcename = newstrcat2 (argv[index], ".sim");
