@@ -410,7 +410,8 @@ genvalue (re)
 	  {
 	    fprintf (ccode, "__ctext= ");
 	    gencproccall (re);
-	      fprintf (ccode, ";__t[%d]= *__rblanks(%ldL,strlen(__ctext));"
+	      fprintf (ccode, ";__t[%d]= *__rblanks(%ldL,"
+		       "__ctext==__NULL?0:strlen(__ctext));"
 		       "(void)strcpy(__t[%d].obj->string,__ctext);",
 		       re->value.combined_stack.entry, 
 		       re->value.combined_stack.n_of_stack_elements, 
@@ -1362,6 +1363,26 @@ genvalue (re)
       fprintf (ccode, ";");
       genvalue (re->right);
       break;
+    case MDIV:
+    case MINTDIV:
+      putc ('(', ccode);
+      genvalue (re->left);
+      fprintf (ccode, "/");
+
+#ifdef DIV0
+      if (re->token == MINTDIV) 
+	fprintf (ccode, "__ridiv0 (");
+      else
+	fprintf (ccode, "__rrdiv0 (");
+#endif /* DIV0 */
+
+      genvalue (re->right);
+      putc (')', ccode);
+
+#ifdef DIV0
+      putc (')', ccode); 
+#endif /* DIV0 */
+      break;
     default:
       putc ('(', ccode);
       if (re->left->type == TCHAR)
@@ -1414,10 +1435,6 @@ genvalue (re)
 	case MMULI:
 	  fprintf (ccode, "*");
 	  break;
-	case MDIV:
-	case MINTDIV:
-	  fprintf (ccode, "/");
-	  break;
 	default:
 #ifdef DEBUG
 	  fprintf (stderr, "Illegal token:%s\n"
